=======
Credits
=======

Development Lead
----------------

* Daniele Antonucci <daniele.antonucci@eurac.edu>
* Ulrich Filippi Oberegger <ulrich.filippi@eurac.edu> 
* Olga Somova <olga.somova@eurac.edu> 

Contributors
------------

None yet. Why not be the first?
